"""Unofficial API wrapper for Metabase
"""

__version__ = "0.10.0"

from metabase_tools.exceptions import (
    AuthenticationFailure,
    EmptyDataReceived,
    InvalidDataReceived,
    InvalidParameters,
    ItemInPersonalCollection,
    ItemNotFound,
    MetabaseApiException,
    NoUpdateProvided,
    RequestFailure,
)
from metabase_tools.metabase import MetabaseApi
from metabase_tools.models.card_model import CardItem, CardQueryResult
from metabase_tools.models.collection_model import CollectionItem
from metabase_tools.models.database_model import DatabaseItem
from metabase_tools.models.user_model import UserItem
from metabase_tools.server_settings import ServerSettings, Setting
from metabase_tools.tools import MetabaseTools

__all__ = (
    "AuthenticationFailure",
    "EmptyDataReceived",
    "InvalidDataReceived",
    "InvalidParameters",
    "ItemNotFound",
    "ItemInPersonalCollection",
    "MetabaseApiException",
    "NoUpdateProvided",
    "RequestFailure",
    "MetabaseApi",
    "CardItem",
    "CardQueryResult",
    "CollectionItem",
    "DatabaseItem",
    "UserItem",
    "MetabaseTools",
    "ServerSettings",
    "Setting",
)



"""Exceptions for the MetabaseApi class
"""


class MetabaseApiException(Exception):
    """Base exception for other exceptions included in this package"""


class AuthenticationFailure(MetabaseApiException):
    """Error encountered while trying to authenticate with API"""


class EmptyDataReceived(MetabaseApiException):
    """Response received but it contained no data"""


class InvalidDataReceived(MetabaseApiException):
    """Data received but it could not be decoded"""


class InvalidParameters(MetabaseApiException):
    """Invalid parameters supplied to API"""


class ItemNotFound(MetabaseApiException):
    """Item was not found it the listed location"""


class ItemInPersonalCollection(MetabaseApiException):
    """Requested item is in a personal collection"""


class RequestFailure(MetabaseApiException):
    """HTTP error encountered during request"""


class NoUpdateProvided(MetabaseApiException):
    """An update was requested but no change was provided"""
